@@ -25,4 +25,5 @@
 #' \item{DB}{Database}
 #' }
 #' @source \url{http://www.webofknowledge.com}
-"isiCollection"
\ No newline at end of file
+#' @name isiCollection
+NULL
\ No newline at end of file
