@@ -5,6 +5,7 @@
 #' @param Nodes is a list of nodes obtained by \code{\link{thematicEvolution}} function.
 #' @param Edges is a list of edges obtained by \code{\link{thematicEvolution}} function.
 #' @param measure is a character. It can be \code{measure=("inclusion","stability")}.
+#' @param min.flow is numerical. It indicates the minimum value of measure to plot a flow.
 #' @return a sankeyPlot
 #' 
 #'
@@ -23,7 +24,7 @@
 #'
 #' @export
 
-plotThematicEvolution<-function(Nodes,Edges,measure="inclusion"){
+plotThematicEvolution<-function(Nodes,Edges,measure="inclusion", min.flow=0){
   
   switch(measure,
          inclusion={
@@ -33,6 +34,7 @@ plotThematicEvolution<-function(Nodes,Edges,measure="inclusion"){
            Edges=Edges[-3]
          })
   names(Edges)[3]="weight"
+  Edges=Edges[Edges$weight>=min.flow,]
   networkD3::sankeyNetwork(Links = Edges, Nodes = Nodes, Source = "from", Target = "to", 
                            NodeID = "name", Value = "weight", width = 900, fontSize = 12,
                            nodeWidth = 30,  NodeGroup = "group",LinkGroup = "group")
